"""
ALT's copy of upstream's numexpr.tests.test_numexpr.print_versions

ALT doesn't ship tests, thus, print_versions is moved out.
"""

import sys

from packaging.version import Version


def get_minimum_numpy_version():
    try:
        from numexpr.tests.test_numexpr import minimum_numpy_version
    except ImportError:
        minimum_numpy_version = None
    return minimum_numpy_version


def print_versions():
    """Print the versions of software that numexpr relies on."""
    from numexpr import use_vml
    import numexpr
    import numpy as np
    minimum_numpy_version = Version('1.7.0')

    # must be synced with numexpr.tests.test_numexpr.minimum_numpy_version
    min_numpy = get_minimum_numpy_version()
    if min_numpy is not None:
        assert (
            min_numpy == minimum_numpy_version
        ), f"Expected: {min_numpy!r}, actual: {minimum_numpy_version!r}"

    # from pkg_resources import parse_version
    from numexpr.cpuinfo import cpu
    import platform

    np_version = Version(np.__version__)

    if np_version < minimum_numpy_version:
        print('*Warning*: NumPy version is lower than recommended: %s < %s' % (np_version, minimum_numpy_version))
    print('-=' * 38)
    print('Numexpr version:   %s' % numexpr.__version__)
    print('NumPy version:     %s' % np.__version__)
    print('Python version:    %s' % sys.version)
    (sysname, nodename, release, os_version, machine, processor) = platform.uname()
    print('Platform:          %s-%s-%s' % (sys.platform, machine, os_version))
    try:
        # cpuinfo doesn't work on OSX well it seems, so protect these outputs 
        # with a try block
        cpu_info = cpu.info[0]
        print('CPU vendor:        %s' % cpu_info.get('VendorIdentifier', ''))
        print('CPU model:         %s' % cpu_info.get('ProcessorNameString', ''))
        print('CPU clock speed:   %s MHz' % cpu_info.get('~MHz',''))
    except KeyError:
        pass
    print('VML available?     %s' % use_vml)
    if use_vml:
        print('VML/MKL version:   %s' % numexpr.get_vml_version())
    print('Number of threads used by default: %d '
          '(out of %d detected cores)' % (numexpr.nthreads, numexpr.ncores))
    print('Maximum number of threads: %s' % numexpr.MAX_THREADS)
    print('-=' * 38)
